********************************************************************************************
*****         Analyse des comportements en situation d'interactions sociales           *****
*****                  et son influence sur la propension  la coopration             *****
********************************************************************************************

cd "E:\Dropbox\Professionnel\03. Recherche\06. Prfrences sociales\04. RBFC"
*cd "D:\Dropbox\Professionnel\Recherche\2016\04. RBFC"

use "Jeu Bien public.dta", clear

*** Analyse des prfrences sociales : Analyse des partages, du seuil d'acceptation et de don reciproque


****** Analyse des contributions dans le jeu du bien public

tabstat q801m, statistics(count median  mean sd min max) by(period) columns(statistics)

sdtest q801m if  period==1| period==2, by( period)
ttest q801m if  period==1| period==2, by( period)

sdtest q801m if  period==2| period==3, by( period)
ttest q801m if  period==2| period==3, by( period)

sdtest q801m if  period==3| period==4, by( period)
ttest q801m if  period==3| period==4, by( period)

sdtest q801m if  period==4| period==5, by( period)
ttest q801m if  period==4| period==5, by( period)

twoway (scatter varicontri ecart_01)

scatter varicontri ecart_01 || lfit varicontri ecart_01, legend(off) xtitle("Contribution gap with group at previous period")  ytitle("Contribution's variation")
*scatter varicontri ecart_01 || lfit varicontri ecart_01, ylabel(#4) xlabel(#4) legend(label("1") width(40) keygap(2) textwidth(100))

regress varicontri ecart_01

xtset id period, yearly
quie xtreg varicontri ecart_01, fe
estimates store fixed
quie xtreg varicontri ecart_01, re
hausman fixed ., sigmamore

quie xtreg varicontri ecart_01, fe
outreg2 using Varicontri

****** Analyse des niveaux de partages

sum q502 if period==1
sum q502 if period==1 & q502 !=0

****** Analyse du seuil d'acceptation

sum seuil if period==1

twoway (scatter seuil q502)

****** Distribution des coefficients de retour a priori 

sum partq701 partq702 partq703 partq704 partq705 partq706 partq707 partq708 partq709 partq710 if period==1

twoway (line Retour Don) (scatter Retour Don)
twoway (scatter Retour Don)

hist q502 if period==1, kdensity
sum seuil if period==1, kdensity

pwcorr partq701 partq702 partq703 partq704 partq705 partq706 partq707 partq708 partq709 partq710, star(0.05)
pwcorr q502 seuil partq701 partq702 partq703 partq704 partq705 partq706 partq707 partq708 partq709 partq710, star(0.05)

pca q502 seuil partq701 partq702 partq703 partq704 partq705 partq706 partq707 partq708 partq709 partq710 


tabstat q502 seuil partq701 partq702 partq703 partq704 partq705 partq706 partq707 partq708 partq709 partq710 if period==1, statistics(median  mean sd min max) by(Social) columns(statistics)

manova q502 seuil partq701 partq702 partq703 partq704 partq705 partq706 partq707 partq708 partq709 partq710 = Social if period==1

****** Graphique combin

sort period
by period : egen RetourDon_m=mean(Retour)
graph drop ShareHist ThreHist RetourHist RetourDonScat

hist q502 if period==1 & q502!=0, kdensity name(ShareHist)  scale(0.6)  title("Histogram of Shares in dictator game") ytitle("percent") xtitle("Share's level (%)") 
hist seuil if period==1, kdensity name(ThreHist)  scale(0.6)  title("Histogram of acceptance's threshold in ultimatum game") ytitle("percent") xtitle("acceptance's threshold (%)") 
hist Retour, kdensity name(RetourHist)  scale(0.6)  title("Histogram of intentionnal reciprocal gift in trust game") ytitle("percent") xtitle("intentionnal reciprocal gift") 
twoway (line RetourDon_m Don) (scatter RetourDon_m Don), legend(off) name(RetourDonScat) title("intentionnal reciprocal gift by initial transfer in trust game") ytitle("intentionnal reciprocal gift") xtitle("Gift (In %)") scale(0.6)

graph combine ShareHist ThreHist RetourHist RetourDonScat, cols(2)

gen logRetourDon_m=log( RetourDon_m)
gen invRetourDon_m=1/ RetourDon_m
gen logDon=log(Don)
gen invDon=1/ Don

reg logRetourDon_m Don
reg invRetourDon_m Don
reg RetourDon_m invDon
reg RetourDon_m logDon
reg logRetourDon_m logDon

drop RetourDon_m logRetourDon_m invRetourDon_m logDon invDon

gen logRetourDon=log(Retour)
gen invRetourDon=1/ Retour
gen logDon=log(Don)
gen invDon=1/ Don

reg logRetourDon Don
reg invRetourDon Don
reg Retour invDon
reg Retour logDon
reg logRetourDon logDon

xtset id period, yearly
xtreg logRetourDon logDon, fe

*** Test de comparaison des moyennes entre les groupes sociaux

mvtest means q502 seuil partq701 partq702 partq703 partq704 partq705 partq706 partq707 partq708 partq709 partq710 if period==1, by(Social)

pwcorr q502 seuil partq701 partq702 partq703 partq704 partq705 partq706 partq707 partq708 partq709 partq710 if period==1
pwcorr q502 seuil partq701 partq702 partq703 partq704 partq705 partq706 partq707 partq708 partq709 partq710 if Social==1 & period==1
pwcorr q502 seuil partq701 partq702 partq703 partq704 partq705 partq706 partq707 partq708 partq709 partq710 if Social==2 & period==1

mvtest cov q502 seuil partq701 partq702 partq703 partq704 partq705 partq706 partq707 partq708 partq709 partq710, by(Social)
mvtest means q502 seuil partq701 partq702 partq703 partq704 partq705 partq706 partq707 partq708 partq709 partq710, by(Social) heterogenous

*** Modlisation des contributions dans le jeu du bien public

countfit q801m i.Social if Social !=. & period==1, inflate(i.Social)
drop PRMval- ZINBabsdif

zinb q801m i.Social if Social !=. & period==1, inflate(i.Social)

countfit VariContriplus i.Social if Social !=., inflate(i.Social)
drop PRMval- ZINBabsdif

zinb VariContriplus i.Social if Social !=., inflate(i.Social)

countfit VariContrimoins i.Social if Social !=., inflate(i.Social)
drop PRMval- ZINBabsdif

zinb VariContrimoins i.Social if Social !=., inflate(i.Social)

countfit VariContriplus i.Social  ecart_01 if Social !=., inflate(i.Social  ecart_01)
drop PRMval- ZINBabsdif

zinb VariContriplus i.Social  ecart_01 if Social !=., inflate(i.Social  ecart_01)

countfit VariContrimoins i.Social  ecart_01 if Social !=., inflate(i.Social  ecart_01)
drop PRMval- ZINBabsdif

zinb VariContrimoins i.Social  ecart_01 if Social !=., inflate(i.Social  ecart_01)

countfit VariContriplus i.Social  ecart_01 Social#c.ecart_01 if Social !=., inflate(i.Social  ecart_01 Social#c.ecart_01)
drop PRMval- ZINBabsdif

zinb VariContriplus i.Social  ecart_01 Social#c.ecart_01 if Social !=., inflate(i.Social  ecart_01 Social#c.ecart_01)

quie logit VariContrizero i.Social
estat ic
quie logit VariContrizero i.Social  ecart_01
estat ic
quie logit VariContrizero i.Social  ecart_01 Social#c.ecart_01
estat ic

*countfit VariContrimoins i.Social  ecart_01 Social#c.ecart_01 if Social !=., inflate(i.Social  ecart_01 Social#c.ecart_01)
*drop PRMval- ZINBabsdif

*zinb VariContrimoins i.Social  ecart_01 Social#c.ecart_01 if Social !=., inflate(i.Social  ecart_01 Social#c.ecart_01)

quie zinb q801m i.Social if Social !=. & period==1, inflate(i.Social)
outreg2 using myfile, replace cttop(full)
quie zinb VariContriplus i.Social  ecart_01 if Social !=., inflate(i.Social  ecart_01)
outreg2 using myfile, e(all)
quie zinb VariContrimoins i.Social  ecart_01 if Social !=., inflate(i.Social  ecart_01)
outreg2 using myfile, e(all)
quie logit VariContrizero i.Social  ecart_01 Social#c.ecart_01
outreg2 using myfile, e(all)


********************************************************************************************
************************************ Fin de l'analyse **************************************
********************************************************************************************

poisson q801m  i.period
nbreg q801m i.period
zip q801m i.period, inflate(i.period) vuong
zinb q801m i.period, inflate(i.period) vuong zip

poisson q801m  contrgroup_01
nbreg q801m contrgroup_01 i.period
zip q801m contrgroup_01 i.period, inflate(q502 seuil) vuong
zinb q801m contrgroup_01 i.period, inflate(q502 seuil) vuong zip

poisson q801m  contrgroup_01 i.period
nbreg q801m contrgroup_01 i.period
zip q801m contrgroup_01 i.period, inflate(q502 seuil) vuong
zinb q801m contrgroup_01 i.period, inflate(q502 seuil) vuong zip

poisson q801m  period#c.contrgroup_01
nbreg q801m period#c.contrgroup_01
zip q801m period#c.contrgroup_01, inflate(q502 seuil) vuong
zinb q801m period#c.contrgroup_01, inflate(q502 seuil) vuong zip

poisson q801m  contrgroup_01 i.period period#c.contrgroup_01
nbreg q801m contrgroup_01 i.period period#c.contrgroup_01
zip q801m contrgroup_01 i.period period#c.contrgroup_01, inflate(q502 seuil) vuong
zinb q801m contrgroup_01 i.period period#c.contrgroup_01, inflate(q502 seuil) vuong zip


poisson q801m  contrgroup_01 q502 seuil partq701 partq702 partq703 partq704 partq705 partq706 partq707 partq708 partq709 partq710 i.period
nbreg q801m contrgroup_01 q502 seuil partq701 partq702 partq703 partq704 partq705 partq706 partq707 partq708 partq709 partq710 i.period
zip q801m contrgroup_01 q502 seuil partq701 partq702 partq703 partq704 partq705 partq706 partq707 partq708 partq709 partq710 i.period, inflate(q502 seuil) vuong
zinb q801m contrgroup_01 q502 seuil partq701 partq702 partq703 partq704 partq705 partq706 partq707 partq708 partq709 partq710 i.period, inflate(q502 seuil) vuong zip

xtset id period, yearly
poisson q801m  contrgroup_01
xtpoisson q801m  contrgroup_01, fe
xtpoisson q801m  contrgroup_01, re

poisson q801m  contrgroup_01 q502 seuil partq701 partq702 partq703 partq704 partq705 partq706 partq707 partq708 partq709 partq710
xtpoisson q801m  contrgroup_01 q502 seuil partq701 partq702 partq703 partq704 partq705 partq706 partq707 partq708 partq709 partq710, fe
xtpoisson q801m  contrgroup_01 q502 seuil partq701 partq702 partq703 partq704 partq705 partq706 partq707 partq708 partq709 partq710, re


countfit q801m i.period i.Social if Social !=. , inflate(i.period  i.Social)
drop PRMval- ZINBabsdif

countfit q801m contrgroup_01 i.Social if Social !=2, inflate(contrgroup_01 i.Social)
drop PRMval- ZINBabsdif

countfit q801m contrgroup_01 i.period i.Social if Social !=2, inflate(contrgroup_01 i.period i.Social)
drop PRMval- ZINBabsdif

countfit q801m period#c.contrgroup_01 i.Social if Social !=2, inflate(period#c.contrgroup_01 i.Social)
drop PRMval- ZINBabsdif

countfit q801m contrgroup_01 i.period period#c.contrgroup_01 i.Social if Social !=2, inflate(contrgroup_01 i.period period#c.contrgroup_01 i.Social)
drop PRMval- ZINBabsdif

countfit q801m  i.Social i.period i.Social if Social !=2, inflate(i.Social i.Social)
drop PRMval- ZINBabsdif

